pub struct PaymentTerms {
pub _type: Option<Type>,
pub discount_percent: Option<String>,
pub discount_due_days: Option<f32>,
pub net_due_days: Option<f32>,
}Expand description
PaymentTerms : Terms of the payment for the invoice. The basis of the payment terms is the invoice date.
Fields
_type: Option<Type>The payment term type for the invoice.
discount_percent: Option<String>A decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Pattern : ^-?(0|([1-9]\\d*))(\\.\\d+)?([eE][+-]?\\d+)?$.
discount_due_days: Option<f32>The number of calendar days from the Base date (Invoice date) until the discount is no longer valid.
net_due_days: Option<f32>The number of calendar days from the base date (invoice date) until the total amount on the invoice is due.
Implementations
sourceimpl PaymentTerms
impl PaymentTerms
sourcepub fn new() -> PaymentTerms
pub fn new() -> PaymentTerms
Terms of the payment for the invoice. The basis of the payment terms is the invoice date.